@@ -57,6 +57,13 @@ class CreateFromFormatTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($d);
     }
 
+    public function testCreateFromFalseTimezone()
+    {
+        $d = Carbon::createFromFormat('Y-m-d H:i:s.u', '1975-05-21 22:32:11.123456', false);
+        $this->assertInstanceOfCarbon($d);
+        $this->assertSame('1975-05-21 22:32:11.123456 America/Toronto', $d->format('Y-m-d H:i:s.u e'));
+    }
+
     /**
      * Work-around for https://bugs.php.net/bug.php?id=80141
      */
@@ -84,12 +91,13 @@ class CreateFromFormatTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($d);
     }
 
+    /**
+     * @requires PHP >= 7.3
+     *
+     * Due to https://bugs.php.net/bug.php?id=75577, proper "v" format support can only works from PHP 7.3.0.
+     */
     public function testCreateFromFormatWithMillisecondsMerged()
     {
-        if (version_compare(PHP_VERSION, '7.3.0-dev', '<')) {
-            $this->markTestSkipped('Due to https://bugs.php.net/bug.php?id=75577, proper "v" format support can only works from PHP 7.3.0.');
-        }
-
         $d = Carbon::createFromFormat('Y-m-d H:s.vi', '1975-05-21 22:11.32132');
         $this->assertCarbon($d, 1975, 5, 21, 22, 32, 11, 321000);
         $this->assertInstanceOfCarbon($d);
