@@ -886,11 +886,6 @@ class IsTest extends AbstractTestCase
         // @see https://github.com/briannesbitt/Carbon/issues/2180
         $this->assertTrue(Carbon::hasFormat('2020-09-01 12:00:00Europe/Moscow', 'Y-m-d H:i:se'));
 
-        if (version_compare(PHP_VERSION, '7.3.0-dev', '>=')) {
-            // Due to https://bugs.php.net/bug.php?id=75577, proper "v" format support can only works from PHP 7.3.0.
-            $this->assertTrue(Carbon::hasFormat('2012-12-04 22:59.32130', 'Y-m-d H:s.vi'));
-        }
-
         // Format failure
         $this->assertFalse(Carbon::hasFormat(null, 'd m Y'));
         $this->assertFalse(Carbon::hasFormat('1975-05-01', 'd m Y'));
@@ -907,6 +902,11 @@ class IsTest extends AbstractTestCase
         $this->assertFalse(Carbon::hasFormat('1975-05-01', 'Y-m-d!'));
         $this->assertFalse(Carbon::hasFormat('1975-05-01', 'Y-m-d|'));
         $this->assertFalse(Carbon::hasFormat('1975-05-01', 'Y-*-d'));
+
+        $this->assertTrue(Carbon::hasFormat('2012-12-04 22:59.32130', 'Y-m-d H:s.vi'));
+
+        // New Zealand Daylight time
+        $this->assertTrue(Carbon::hasFormat('2024-03-02T00:00:00+13:00', 'Y-m-d\TH:i:sP'));
     }
 
     public function testHasFormatWithModifiers()
@@ -1035,6 +1035,9 @@ class IsTest extends AbstractTestCase
         $this->assertTrue(Carbon::parse('2019-06-02 12:23:45')->is('Sunday'));
         $this->assertFalse(Carbon::parse('2019-06-02 12:23:45')->is('Monday'));
         $this->assertTrue(Carbon::parse('2019-06-02 12:23:45')->is('June'));
+        $this->assertTrue(Carbon::parse('2019-05-31 12:23:45')->is('May'));
+        $this->assertTrue(Carbon::parse('2019-05-31 12:23:45')->is('mAy'));
+        $this->assertFalse(Carbon::parse('2019-05-31 12:23:45')->is('April'));
         $this->assertFalse(Carbon::parse('2019-06-02 12:23:45')->is('May'));
         $this->assertTrue(Carbon::parse('2019-06-02 12:23:45')->is('12:23'));
         $this->assertFalse(Carbon::parse('2019-06-02 12:23:45')->is('12:26'));
