@@ -242,7 +242,7 @@ class SettersTest extends AbstractTestCase
         $this->assertSame('2020-09-23 14:52:44.889523', $d->format('Y-m-d H:i:s.u'));
 
         $d->setTimestamp(1599828571.23561248);
-        $this->assertSame('2020-09-11 08:49:31.235612', $d->format('Y-m-d H:i:s.u'));
+        $this->assertSame(PHP_VERSION_ID < 80400 ? '2020-09-11 08:49:31.235612' : '2020-09-11 08:49:31.235613', $d->format('Y-m-d H:i:s.u'));
 
         $d->timestamp = '0.88951247 1600887164';
         $this->assertSame('2020-09-23 14:52:44.889512', $d->format('Y-m-d H:i:s.u'));
@@ -330,7 +330,7 @@ class SettersTest extends AbstractTestCase
         /** @var array $array */
         $array = $date;
 
-        foreach ($array as $_) {
+        foreach ($array as $item) {
         }
 
         $date->cleanupDumpProperties()->timezone = 'UTC';
@@ -859,6 +859,9 @@ class SettersTest extends AbstractTestCase
         $this->assertSame(static::SET_UNIT_NO_OVERFLOW_SAMPLE, $results['end'] + $results['start'] + $results['current']);
     }
 
+    /**
+     * @SuppressWarnings(PHPMD.TooManyFields)
+     */
     private function failOperation(
         Carbon $original,
         Carbon $date,
