@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -9,9 +10,12 @@ declare(strict_types=1);
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+
 namespace Tests\Carbon;
 
 use Carbon\Carbon;
+use Generator;
+use InvalidArgumentException;
 use Tests\AbstractTestCase;
 
 class StartEndOfTest extends AbstractTestCase
@@ -438,26 +442,24 @@ class StartEndOfTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($dt->startOfQuarter());
     }
 
-    public function dataProviderTestStartOfQuarter()
+    public static function dataForTestStartOfQuarter(): Generator
     {
-        return [
-            [1, 1],
-            [2, 1],
-            [3, 1],
-            [4, 4],
-            [5, 4],
-            [6, 4],
-            [7, 7],
-            [8, 7],
-            [9, 7],
-            [10, 10],
-            [11, 10],
-            [12, 10],
-        ];
+        yield [1, 1];
+        yield [2, 1];
+        yield [3, 1];
+        yield [4, 4];
+        yield [5, 4];
+        yield [6, 4];
+        yield [7, 7];
+        yield [8, 7];
+        yield [9, 7];
+        yield [10, 10];
+        yield [11, 10];
+        yield [12, 10];
     }
 
     /**
-     * @dataProvider \Tests\Carbon\StartEndOfTest::dataProviderTestStartOfQuarter
+     * @dataProvider \Tests\Carbon\StartEndOfTest::dataForTestStartOfQuarter
      *
      * @param int $month
      * @param int $startOfQuarterMonth
@@ -474,26 +476,24 @@ class StartEndOfTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($dt->endOfQuarter());
     }
 
-    public function dataProviderTestEndOfQuarter()
+    public static function dataForTestEndOfQuarter(): Generator
     {
-        return [
-            [1, 3, 31],
-            [2, 3, 31],
-            [3, 3, 31],
-            [4, 6, 30],
-            [5, 6, 30],
-            [6, 6, 30],
-            [7, 9, 30],
-            [8, 9, 30],
-            [9, 9, 30],
-            [10, 12, 31],
-            [11, 12, 31],
-            [12, 12, 31],
-        ];
+        yield [1, 3, 31];
+        yield [2, 3, 31];
+        yield [3, 3, 31];
+        yield [4, 6, 30];
+        yield [5, 6, 30];
+        yield [6, 6, 30];
+        yield [7, 9, 30];
+        yield [8, 9, 30];
+        yield [9, 9, 30];
+        yield [10, 12, 31];
+        yield [11, 12, 31];
+        yield [12, 12, 31];
     }
 
     /**
-     * @dataProvider \Tests\Carbon\StartEndOfTest::dataProviderTestEndOfQuarter
+     * @dataProvider \Tests\Carbon\StartEndOfTest::dataForTestEndOfQuarter
      *
      * @param int $month
      * @param int $endOfQuarterMonth
@@ -570,20 +570,18 @@ class StartEndOfTest extends AbstractTestCase
 
     public function testStartOfInvalidUnit()
     {
-        $this->expectException(\InvalidArgumentException::class);
-        $this->expectExceptionMessage(
+        $this->expectExceptionObject(new InvalidArgumentException(
             'Unknown unit \'microsecond\''
-        );
+        ));
 
         Carbon::now()->startOf('microsecond');
     }
 
     public function testEndOfInvalidUnit()
     {
-        $this->expectException(\InvalidArgumentException::class);
-        $this->expectExceptionMessage(
+        $this->expectExceptionObject(new InvalidArgumentException(
             'Unknown unit \'microsecond\''
-        );
+        ));
 
         Carbon::now()->endOf('microsecond');
     }
