@@ -15,6 +15,7 @@ namespace Tests\CarbonImmutable;
 
 use BadMethodCallException;
 use Carbon\CarbonImmutable as Carbon;
+use CarbonTimezoneTrait;
 use Tests\AbstractTestCaseWithOldNow;
 use Tests\Carbon\Fixtures\FooBar;
 use Tests\CarbonImmutable\Fixtures\Mixin;
@@ -81,7 +82,7 @@ class MacroTest extends AbstractTestCaseWithOldNow
         $this->assertSame('05/04', Carbon::easterDate(2015)->format('d/m'));
     }
 
-    public function testCarbonIsMacroableWhithNonClosureCallables()
+    public function testCarbonIsMacroableWithNonClosureCallables()
     {
         Carbon::macro('lower2', 'strtolower');
 
@@ -135,4 +136,34 @@ class MacroTest extends AbstractTestCaseWithOldNow
 
         $this->assertInstanceOf(Carbon::class, Carbon::me());
     }
+
+    /**
+     * @requires PHP >= 8.0
+     */
+    public function testTraitWithNamedParameters()
+    {
+        require_once __DIR__.'/../Fixtures/CarbonTimezoneTrait.php';
+
+        Carbon::mixin(CarbonTimezoneTrait::class);
+        $now = Carbon::now();
+        $now = eval("return \$now->toAppTz(tz: 'Europe/Paris');");
+
+        $this->assertSame('Europe/Paris', $now->format('e'));
+    }
+
+    public function testSerializationAfterTraitChaining()
+    {
+        require_once __DIR__.'/../Fixtures/CarbonTimezoneTrait.php';
+
+        Carbon::mixin(CarbonTimezoneTrait::class);
+        Carbon::setTestNow('2023-05-24 14:49');
+
+        $date = Carbon::toAppTz(false, 'Europe/Paris');
+
+        $this->assertSame('2023-05-24 16:49 Europe/Paris', unserialize(serialize($date))->format('Y-m-d H:i e'));
+
+        $date = Carbon::parse('2023-06-12 11:49')->toAppTz(false, 'Europe/Paris');
+
+        $this->assertSame('2023-06-12 13:49 Europe/Paris', unserialize(serialize($date))->format('Y-m-d H:i e'));
+    }
 }
