@@ -33,23 +33,24 @@ class ToStringTest extends AbstractTestCase
         );
     }
 
-    public static function dataForToString(): Generator
+    public function dataForToString(): Generator
     {
+        $periodClass = $this->periodClass;
         Carbon::setTestNowAndTimezone(new Carbon('2015-09-01', 'America/Toronto'));
 
         yield [
-                CarbonPeriod::create('R4/2012-07-01T12:00:00/P7D'),
+                $periodClass::create('R4/2012-07-01T12:00:00/P7D'),
                 '4 times every 1 week from 2012-07-01 12:00:00',
             ];
         yield [
-                CarbonPeriod::create(
+                $periodClass::create(
                     Carbon::parse('2015-09-30'),
                     Carbon::parse('2015-10-03')
                 ),
                 'Every 1 day from 2015-09-30 to 2015-10-03',
             ];
         yield [
-                CarbonPeriod::create(
+                $periodClass::create(
                     Carbon::parse('2015-09-30 12:50'),
                     CarbonInterval::days(3)->hours(5),
                     Carbon::parse('2015-10-03 19:00')
@@ -57,19 +58,19 @@ class ToStringTest extends AbstractTestCase
                 'Every 3 days and 5 hours from 2015-09-30 12:50:00 to 2015-10-03 19:00:00',
             ];
         yield [
-                CarbonPeriod::create('2015-09-30 17:30'),
+                $periodClass::create('2015-09-30 17:30'),
                 'Every 1 day from 2015-09-30 17:30:00',
             ];
         yield [
-                CarbonPeriod::create('P1M14D'),
+                $periodClass::create('P1M14D'),
                 'Every 1 month and 2 weeks from 2015-09-01',
             ];
         yield [
-                CarbonPeriod::create('2015-09-30 13:30', 'P17D')->setRecurrences(1),
+                $periodClass::create('2015-09-30 13:30', 'P17D')->setRecurrences(1),
                 'Once every 2 weeks and 3 days from 2015-09-30 13:30:00',
             ];
         yield [
-                CarbonPeriod::create('2015-10-01', '2015-10-05', 'PT30M'),
+                $periodClass::create('2015-10-01', '2015-10-05', 'PT30M'),
                 'Every 30 minutes from 2015-10-01 to 2015-10-05',
             ];
 
@@ -78,7 +79,8 @@ class ToStringTest extends AbstractTestCase
 
     public function testMagicToString()
     {
-        $period = CarbonPeriod::create(
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create(
             Carbon::parse('2015-09-30 12:50'),
             CarbonInterval::days(3)->hours(5),
             Carbon::parse('2015-10-03 19:00')
@@ -101,23 +103,24 @@ class ToStringTest extends AbstractTestCase
         );
     }
 
-    public static function dataForToIso8601String(): Generator
+    public function dataForToIso8601String(): Generator
     {
+        $periodClass = $this->periodClass;
         Carbon::setTestNowAndTimezone(new Carbon('2015-09-01', 'America/Toronto'));
 
         yield [
-                CarbonPeriod::create('R4/2012-07-01T00:00:00-04:00/P7D'),
+                $periodClass::create('R4/2012-07-01T00:00:00-04:00/P7D'),
                 'R4/2012-07-01T00:00:00-04:00/P7D',
             ];
         yield [
-                CarbonPeriod::create(
+                $periodClass::create(
                     Carbon::parse('2015-09-30', 'America/Toronto'),
                     Carbon::parse('2015-10-03', 'America/Toronto')
                 ),
                 '2015-09-30T00:00:00-04:00/P1D/2015-10-03T00:00:00-04:00',
             ];
         yield [
-                CarbonPeriod::create(
+                $periodClass::create(
                     Carbon::parse('2015-09-30 12:50', 'America/Toronto'),
                     CarbonInterval::days(3)->hours(5),
                     Carbon::parse('2015-10-03 19:00', 'America/Toronto')
@@ -125,21 +128,22 @@ class ToStringTest extends AbstractTestCase
                 '2015-09-30T12:50:00-04:00/P3DT5H/2015-10-03T19:00:00-04:00',
             ];
         yield [
-                CarbonPeriod::create(
+                $periodClass::create(
                     Carbon::parse('2015-09-30 12:50', 'America/Toronto'),
                     CarbonInterval::days(3)
                 ),
                 '2015-09-30T12:50:00-04:00/P3D',
             ];
         yield [
-                CarbonPeriod::create(),
+                $periodClass::create(),
                 '2015-09-01T00:00:00-04:00/P1D',
             ];
     }
 
     public function testSpec()
     {
-        $period = CarbonPeriod::create(
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create(
             Carbon::parse('2015-09-30'),
             CarbonInterval::days(3)->hours(5),
             Carbon::parse('2015-10-03')
@@ -153,9 +157,10 @@ class ToStringTest extends AbstractTestCase
 
     public function testStartOfWeekForPeriod()
     {
+        $periodClass = $this->periodClass;
         $sunday = CarbonImmutable::parse('2019-12-01');
 
-        $period = CarbonPeriod::create($sunday->startOfWeek(), '1 week', $sunday->endOfWeek())->toArray();
+        $period = $periodClass::create($sunday->startOfWeek(), '1 week', $sunday->endOfWeek())->toArray();
 
         $formattedSunday = $sunday->startOfWeek()->format('Y-m-d H:i:s');
 
@@ -172,16 +177,17 @@ class ToStringTest extends AbstractTestCase
 
     public function testToStringCustomization()
     {
+        $periodClass = $this->periodClass;
         $sunday = CarbonImmutable::parse('2019-12-01');
 
-        $period = CarbonPeriod::create($sunday->startOfWeek(), '1 week', $sunday->endOfWeek());
+        $period = $periodClass::create($sunday->startOfWeek(), '1 week', $sunday->endOfWeek());
 
         $this->assertSame(
             'Every 1 week from 2019-11-25 00:00:00 to 2019-12-01 23:59:59!!',
             $period.'!!'
         );
 
-        CarbonPeriod::setToStringFormat('m/d');
+        $periodClass::setToStringFormat('m/d');
 
         $this->assertSame(
             'Every 1 week from 11/25 to 12/01!!',
@@ -197,6 +203,6 @@ class ToStringTest extends AbstractTestCase
             $period.'!!'
         );
 
-        CarbonPeriod::resetToStringFormat();
+        $periodClass::resetToStringFormat();
     }
 }
