@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -9,8 +10,10 @@ declare(strict_types=1);
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+
 namespace Tests\Cli;
 
+use Carbon\Cli;
 use Carbon\Cli\Invoker;
 use Tests\AbstractTestCase;
 
@@ -46,6 +49,6 @@ class InvokerTest extends AbstractTestCase
         $this->assertNull($lastCommand);
         $this->assertSame('', $contents);
         $this->assertTrue($return);
-        $this->assertSame(['file', 'install', $exec], \Carbon\Cli::$lastParameters);
+        $this->assertSame(['file', 'install', $exec], Cli::$lastParameters);
     }
 }
