@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -9,6 +10,7 @@ declare(strict_types=1);
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+
 namespace Tests\Localization;
 
 use Tests\AbstractTestCase;
@@ -24,9 +26,10 @@ class LanguagesCoverageTest extends AbstractTestCase
         $tester = $this;
         $missingLanguages = array_filter($languages, function ($language) use ($tester, $tests) {
             $file = basename($language);
-            $covered = in_array(
+            $covered = \in_array(
                 str_replace(['_', '-', '@'], '', strtolower(substr($file, 0, -4))),
-                $tests
+                $tests,
+                true
             );
             $tester->assertTrue($covered, "Expect $file language file to be covered.");
 
