@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -9,13 +10,17 @@ declare(strict_types=1);
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+
 namespace Tests\Localization;
 
+/**
+ * @group localization
+ */
 class MyMmTest extends LocalizationTestCase
 {
-    const LOCALE = 'my_MM'; // Burmese
+    public const LOCALE = 'my_MM'; // Burmese
 
-    const CASES = [
+    public const CASES = [
         // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
         // 'Tomorrow at 12:00 AM',
         'မနက်ဖြန် ၁၂:၀၀ နံနက် မှာ',
